==> ngx_core-0.2.0.tar.gz: lib/src/services/configuration.dart <==
part of ngx_core;

/// Provides access to the application configuration.
@Injectable()
class Configuration extends MapBase<String, dynamic> {

  /// The handler of "changes" events.
  final StreamController<Map<String, SimpleChange>> _onChanges = new StreamController<Map<String, SimpleChange>>.broadcast();

  /// The custom application parameters.
  final Map<String, dynamic> _params;

  /// Creates a new configuration service.
  Configuration(@Inject(configToken) Map<String, dynamic> params): _params = new Map.from(params);

  /// The keys of this configuration.
  @override
  Iterable<String> get keys => _params.keys;

  /// The stream of "changes" events.
  Stream<Map<String, SimpleChange>> get onChanges => _onChanges.stream;

  /// Returns the value for the given [key] or `null` if [key] is not in this configuration.
  @override
  dynamic operator [](Object key) => _params[key];

  /// Associates the [key] with the given [value].
  @override
  void operator []=(String key, value) {
    var previousValue = this[key];
    _params[key] = value;
    _onChanges.add({
      key: new SimpleChange(previousValue, value)
    });
  }

  /// Removes all pairs from this configuration.
  @override
  void clear() {
    var changes = new Map.fromIterables(keys, keys.map((key) => new SimpleChange(this[key], null)));
    _params.clear();
    _onChanges.add(changes);
  }

  /// Removes the specified [key] and its associated value from this configuration.
  /// Returns the value associated with [key] before it was removed.
  @override
  dynamic remove(Object key) {
    var previousValue = _params.remove(key);
    _onChanges.add({
      key: new SimpleChange(previousValue, null)
    });

    return previousValue;
  }
}

==> ngx_core-0.6.0.tar.gz: lib/src/services/configuration.dart <==
part of ngx_core;

/// Provides access to the application configuration.
@Injectable()
class Configuration extends MapBase<String, dynamic> {

  /// The handler of "changes" events.
  final StreamController<Map<String, SimpleChange>> _onChanges = new StreamController<Map<String, SimpleChange>>.broadcast();

  /// The custom application parameters.
  final Map<String, dynamic> _params;

  /// Creates a new configuration service.
  Configuration(@Inject(configToken) @Optional() Map<String, dynamic> params):
    _params = new Map<String, dynamic>.from(params ?? const <String, dynamic>{});

  /// The keys of this configuration.
  @override
  Iterable<String> get keys => _params.keys;

  /// The stream of "changes" events.
  Stream<Map<String, SimpleChange>> get onChanges => _onChanges.stream;

  /// Returns the value for the given [key] or `null` if [key] is not in this configuration.
  @override
  dynamic operator [](Object key) => _params[key];

  /// Associates the [key] with the given [value].
  @override
  void operator []=(String key, Object value) {
    var previousValue = this[key];
    _params[key] = value;
    _onChanges.add({
      'key': new SimpleChange(previousValue, value)
    });
  }

  /// Removes all pairs from this configuration.
  @override
  void clear() {
    var changes = new Map.fromIterable(keys, value: (key) => new SimpleChange(this[key], null));
    _params.clear();
    _onChanges.add(changes);
  }

  /// Removes the specified [key] and its associated value from this configuration.
  /// Returns the value associated with [key] before it was removed.
  @override
  dynamic remove(Object key) {
    var previousValue = _params.remove(key);
    _onChanges.add({
      'key': new SimpleChange(previousValue, null)
    });

    return previousValue;
  }
}
